summaryrefslogtreecommitdiff
path: root/nuttx/configs/mcu123-lpc214x/src/up_composite.c
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2013-09-25 18:50:14 -0600
committerGregory Nutt <gnutt@nuttx.org>2013-09-25 18:50:14 -0600
commit97ef769f2d180b5809c2f9513cf4bb66de1f2595 (patch)
treeae801e098a52399edee7d6a322c486a92b5fd499 /nuttx/configs/mcu123-lpc214x/src/up_composite.c
parent54cd9689cccad1949c067f40d500491851799221 (diff)
downloadpx4-nuttx-97ef769f2d180b5809c2f9513cf4bb66de1f2595.tar.gz
px4-nuttx-97ef769f2d180b5809c2f9513cf4bb66de1f2595.tar.bz2
px4-nuttx-97ef769f2d180b5809c2f9513cf4bb66de1f2595.zip
Mov apps/examples/composite to apps/system/composite; convert configs/stm3210e-eval/composite to use kconfig-frontend tools -- untested
Diffstat (limited to 'nuttx/configs/mcu123-lpc214x/src/up_composite.c')
-rw-r--r--nuttx/configs/mcu123-lpc214x/src/up_composite.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/configs/mcu123-lpc214x/src/up_composite.c b/nuttx/configs/mcu123-lpc214x/src/up_composite.c
index b62519d52..2a2e2c493 100644
--- a/nuttx/configs/mcu123-lpc214x/src/up_composite.c
+++ b/nuttx/configs/mcu123-lpc214x/src/up_composite.c
@@ -55,8 +55,8 @@
/* Configuration ************************************************************/
-#ifndef CONFIG_EXAMPLES_COMPOSITE_DEVMINOR1
-# define CONFIG_EXAMPLES_COMPOSITE_DEVMINOR1 0
+#ifndef CONFIG_SYSTEM_COMPOSITE_DEVMINOR1
+# define CONFIG_SYSTEM_COMPOSITE_DEVMINOR1 0
#endif
/* PORT and SLOT number probably depend on the board configuration */
@@ -105,7 +105,7 @@
int composite_archinitialize(void)
{
/* If examples/composite is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.
*
@@ -138,7 +138,7 @@ int composite_archinitialize(void)
message("composite_archinitialize: Binding SPI port %d to MMC/SD slot %d\n",
LPC214X_MMCSDSPIPORTNO, LPC214X_MMCSDSLOTNO);
- ret = mmcsd_spislotinitialize(CONFIG_EXAMPLES_COMPOSITE_DEVMINOR1, LPC214X_MMCSDSLOTNO, spi);
+ ret = mmcsd_spislotinitialize(CONFIG_SYSTEM_COMPOSITE_DEVMINOR1, LPC214X_MMCSDSLOTNO, spi);
if (ret < 0)
{
message("composite_archinitialize: Failed to bind SPI port %d to MMC/SD slot %d: %d\n",
@@ -105,7 +105,7 @@
int composite_archinitialize(void)
{
- /* If examples/composite is built as an NSH command, then SD slot should
+ /* If system/composite is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.